@@ -303,8 +303,9 @@ class Array_then_file_seek_backend(object):
     def close(self):
         """Write the in-memory portion to disk, leave the already-on-disk portion unchanged."""
         os.lseek(self.file_, 0, os.SEEK_SET)
+        # This is terribly slow, but it should work
         for index in range(self.bytes_in_memory):
-            self.file_.write(self.array_[index])
+            os.write(self.file_, bytes([self.array_[index]]))
 
         os.close(self.file_)
 
@@ -541,3 +542,7 @@ class Bloom_filter(object):
             if not self.backend.is_set(bitno):
                 return False
         return True
+
+    def close(self):
+        """Close the file, if any."""
+        self.backend.close()
